package p09_klasy;

public class Konto {
    private final int numer;
    private int saldo;
    private Osoba wlasciciel;

    public Konto(int numer, int saldo, Osoba wlasciciel) {
        if(saldo < 0) {
            throw new IllegalArgumentException("Ujemne saldo w konstruktorze");
        }
        this.numer = numer;
        this.saldo = saldo;
        this.wlasciciel = wlasciciel;
    }

    public Konto(int numer, Osoba wlasciciel) {
        this.numer = numer;
        this.saldo = 0;
        this.wlasciciel = wlasciciel;
    }

    // Dla pola numer nie tworzę settera, gdyż numer konta się nie zmienia.
    // Dodatkowo jest to zapewnione modyfikatorem final.
    public int getNumer() {
        return numer;
    }

    // Dla pola saldo nie tworzę settera, gdyż salda nie ustawia się "bez żadnego trybu",
    // tylko saldo można zmodyfikować poprzez operacje biznesowe: wplata, wyplata, przelew.
    public int getSaldo() {
        return saldo;
    }

    public Osoba getWlasciciel() {
        return wlasciciel;
    }

    public void setWlasciciel(Osoba wlasciciel) {
        this.wlasciciel = wlasciciel;
    }

    @Override
    public String toString() {
        return "Konto{" +
                "numer=" + numer +
                ", saldo=" + saldo +
                ", wlasciciel=" + wlasciciel +
                '}';
    }

    public void wplata(int kwota) {
        if(kwota <= 0) {
            throw new IllegalArgumentException("Niedodatnia kwota w metodzie wplata");
        }
        saldo += kwota;
    }

    public void wyplata(int kwota) throws BrakSrodkow {
        if(kwota <= 0) {
            throw new IllegalArgumentException("Niedodatnia kwota w metodzie wyplata");
        }
        if(kwota > saldo) {
            throw new BrakSrodkow("Za mało kasy na koncie nr " + numer);
        }
        saldo -= kwota;
    }

    public void przelew(int kwota, Konto kontoDocelowe) throws BrakSrodkow {
        if(kwota <= 0) {
            throw new IllegalArgumentException("Kwota nie jest dodatnia");
        }
        if(kwota > saldo) {
            throw new BrakSrodkow("Za mało kasy podczas przelewu");
        }
        this.saldo -= kwota;
        kontoDocelowe.saldo += kwota;
    }
}
